<?php

namespace Drupal\ddna\Plugin\Seed;

use Drupal\ddna\Annotation\Seed;
use Drupal\ddna\SeedPluginBase;

/**
 * Plugin implementation of the seed.
 *
 * @Seed(
 *   id = "bundle_type_config_extractor",
 *   label = @Translation("Bundle Type Config Extractor"),
 *   description = @Translation("Bundle Type Config Extractor.")
 * )
 */
class BundleTypeConfigExtractor extends SeedPluginBase {

  public function getElements() {
    $table_rows = [];
    $table_header = [
      'Name',
      'Machine name',
      'Bundle entity name',
      'Description',
      'Example(s)',
      'Moderated',
      'Layout builder',
      'Translatable',
      'Migrated (Content will be populated via migration)',
      'Schedulable (Scheduled updates are enabled)',
      'Searchable (Is indexed for site search)',
      'Type',
      'Url alias pattern',
    ];
    $ddna_config_matcher = \Drupal::service('ddna_config_matcher');
    $configs = $ddna_config_matcher->matchAllConfigs($this->configuration['params']['regexp']);
    foreach ($configs as $element) {
      [$machine_name,,] = explode('.', $element);
      /* @var \Drupal\Core\Entity\EntityTypeInterface $definition */
      $definition = \Drupal::entityTypeManager()->getDefinition($machine_name);
      $table_rows[] = [
        (string) $definition->getLabel(),
        $definition->id(),
        $definition->getBundleEntityType(),
        '',
        '-',
        '-',
        '-',
        $definition->isTranslatable() ? 'Yes' : 'No',
        '-',
        '-',
        '-',
        $definition->getBundleLabel(),
        '-',
      ];
    }

    return [$table_header, $table_rows];
  }
}
