<?php

namespace Drupal\ddna\Plugin\Seed;

use Drupal\ddna\Annotation\Seed;
use Drupal\ddna\SeedPluginBase;
use Drupal\field\FieldConfigInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\field\FieldStorageConfigInterface;

/**
 * Plugin implementation of the seed.
 *
 * @Seed(
 *   id = "field_type_config_extractor",
 *   label = @Translation("Field Type Config Extractor"),
 *   description = @Translation("Field Type Config Extractor.")
 * )
 */
class FieldTypeConfigExtractor extends SeedPluginBase {
  public function getElements() {
    $table_rows = [];
    $table_header = [
      'Bundle',
      'Field label',
      'Machine name',
      'Field group',
      'Field type',
      'Target bundle for reference fields',
      'Required',
      'Allowed number of values Asterisk (*) means unlimited',
      'Form widget',
      'Help text',
    ];
    $ddna_config_matcher = \Drupal::service('ddna_config_matcher');
    $configs = $ddna_config_matcher->matchAllConfigs($this->configuration['params']['regexp']);
    foreach ($configs as $element) {
      [,,$entity_type_id, $bundle] = explode('.', $element);
      $base_fields_definition = \Drupal::service('entity_field.manager')->getBaseFieldDefinitions($entity_type_id);
      $fields_definition = \Drupal::service('entity_field.manager')->getFieldDefinitions($entity_type_id, $bundle);
      $field_storage_definition = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions($entity_type_id);
      $active_field_storage_definition = \Drupal::service('entity_field.manager')->getActiveFieldStorageDefinitions($entity_type_id);
      $extra_fields = \Drupal::service('entity_field.manager')->getExtraFields($entity_type_id, $bundle);

      $exportable_fields = [];
      foreach($fields_definition as $definition) {
        /* @var FieldConfigInterface $definition */
        if(!$definition instanceof FieldConfigInterface) {
          continue;
        }

        $table_rows[] = [
          $definition->getDependencies()['config'][0],
          $definition->getLabel(),
          $definition->getName(),
          '-',
          $definition->getType(),
          empty($definition->referencedEntities()) ? '-' : 'array',
          $definition->isRequired() ? 'Yes' : 'No',
          $field_storage_definition[$definition->getName()]->getCardinality(),
          '-',
          '-',
        ];
//        dump($table_rows);die;
      }

    }

    return [$table_header, $table_rows];
  }
}
