<?php

namespace Drupal\ddna\Plugin\Seed;

use Drupal\ddna\Annotation\Seed;
use Drupal\ddna\SeedPluginBase;
use Drupal\views\Views;

/**
 * Plugin implementation of the seed.
 *
 * @Seed(
 *   id = "view_type_config_extractor",
 *   label = @Translation("Views Type Config Extractor"),
 *   description = @Translation("Views Type Config Extractor.")
 * )
 */
class ViewTypeConfigExtractor extends SeedPluginBase {
  public function getElements() {
    $table_rows = [];
    $table_header = [
      'View name',
      'Base table',
      'Machine name',
      'Display machine name',
      'Display plugin',
      'Status',
      'Description',
    ];
    $ddna_config_matcher = \Drupal::service('ddna_config_matcher');
    $configs = $ddna_config_matcher->matchAllConfigs($this->configuration['params']['regexp']);
    $views = \Drupal::entityTypeManager()->getStorage('view')->loadMultiple();

    $views_displays_data = [];
    $views_displays = Views::getViewsAsOptions();
    foreach($views_displays as $config => $view) {
      [$view_machine_name, $display] = explode(':', $config);
      if (empty($views_displays_data[$view_machine_name])) {
        $views_displays_data[$view_machine_name] = [];
      }
      $views_displays_data[$view_machine_name][] = $display;
    }

    foreach ($configs as $element) {
      [,, $view_id] = explode('.', $element);
      foreach($views_displays_data[$view_id] as $display) {
        $display = $views[$view_id]->getDisplay($display);
        $table_rows[] = [
          $views[$view_id]->label(),
          $views[$view_id]->get('base_table'),
          $views[$view_id]->id(),
          $display['id'],
          $display['display_plugin'],
          $views[$view_id]->status() ? 'Enabled' : 'Disabled',
          $views[$view_id]->get('description'),
        ];
      }
    }

    return [$table_header, $table_rows];
  }
}
